summaryrefslogtreecommitdiff
path: root/scene
diff options
context:
space:
mode:
authorOsamaElHariri <ose05@mail.aub.edu>2018-10-10 00:36:12 +0300
committerOsamaElHariri <ose05@mail.aub.edu>2018-10-10 00:36:12 +0300
commit317f7c91a22215205f2d4ae26724e322b702373f (patch)
tree9e717ed4d4cfd9adaba805beb730ebf20f36310d /scene
parent4c1a5d9cfe2da761bfe17d52126deabc1f1c1bd3 (diff)
A colon ending a comment line no longer indents the next line
Diffstat (limited to 'scene')
-rw-r--r--scene/gui/text_edit.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/scene/gui/text_edit.cpp b/scene/gui/text_edit.cpp
index 32580a5ae6..f8a5c4cea3 100644
--- a/scene/gui/text_edit.cpp
+++ b/scene/gui/text_edit.cpp
@@ -2331,9 +2331,9 @@ void TextEdit::_gui_input(const Ref<InputEvent> &p_gui_input) {
// no need to indent if we are going upwards.
if (auto_indent && !(k->get_command() && k->get_shift())) {
// indent once again if previous line will end with ':' or '{'
// (i.e. colon/brace precedes current cursor position)
- if (cursor.column > 0 && (text[cursor.line][cursor.column - 1] == ':' || text[cursor.line][cursor.column - 1] == '{')) {
+ if (cursor.column > 0 && (text[cursor.line][cursor.column - 1] == ':' || text[cursor.line][cursor.column - 1] == '{') && !is_line_comment(cursor.line)) {
if (indent_using_spaces) {
ins += space_indent;
} else {
@@ -2331,9 +2331,9 @@ void TextEdit::_gui_input(const Ref<InputEvent> &p_gui_input) {
// no need to indent if we are going upwards.
if (auto_indent && !(k->get_command() && k->get_shift())) {
- // indent once again if previous line will end with ':' or '{'
+ // indent once again if previous line will end with ':' or '{' and the line is not a comment
// (i.e. colon/brace precedes current cursor position)